import { ref, reactive } from 'vue'
import { TASK_MODE, TASK_TYPE } from '@/utils/dictionary.js'
import { airportList, airportLine } from '@/api/dashboard/index.js'
import { dataToSelect } from '@/utils/handleData.js'

const airOptions = ref([])
const lineOptions = ref([])

function disableTime(ts) {
  const DATE = new Date().getDate()
  const HOURS = new Date().getHours()
  const MINUTES = new Date().getMinutes()
  const SECONDS = new Date().getSeconds()
  const tDate = new Date(ts).getDate()
  const tHours = new Date(ts).getHours()
  const tMinutes = new Date(ts).getMinutes()
  return {
    isHourDisabled: (hour) => {
      return tDate === DATE && hour < HOURS
    },
    isMinuteDisabled: (minute) => {
      if (tDate === DATE) {
        if (tHours < HOURS) {
          return true
        } else {
          return minute < MINUTES
        }
      } else {
        return false
      }
    },
    isSecondDisabled: (second) => {
      if (tDate === DATE) {
        if (tHours < HOURS) {
          return true
        } else if (tMinutes < MINUTES) {
          return true
        } else {
          return second < SECONDS
        }
      } else {
        return false
      }
      // return tDate === DATE && tHours <= HOURS && tMinutes <= MINUTES && second < SECONDS
    }
  }
}

export const form = reactive({
  taskForm: {
    name: '',
    inspectionType: '',
    airportId: '',
    inspectionLine: '',
    type: '',
    executionStartTime: null,
    note: ''
  },
  taskRules: {
    name: [{ required: true, message: '请输入任务名称', trigger: 'blur' }],
    inspectionType: [{ required: true, type: 'number', message: '请选择巡检方式', trigger: 'blur' }],
    airportId: [{ required: true, type: 'number', message: '请选择巡检机场', trigger: 'blur' }],
    inspectionLine: [{ required: true, type: 'number', message: '请选择巡检路线', trigger: 'blur' }],
    type: [{ required: true, type: 'number', message: '请选择任务类型', trigger: 'blur' }],
    executionStartTime: [{ required: true, type: 'date', message: '请选择巡检时间', trigger: ['blur', 'change'] }]
  },
  formItem: [
    { type: 'input', key: 'name', label: '任务名称' },
    { type: 'select', key: 'inspectionType', label: '巡检方式', props: { options: TASK_MODE }},
    { type: 'select', key: 'airportId', label: '巡检机场', props: { options: airOptions }},
    { type: 'select', key: 'inspectionLine', label: '巡检路线', props: { options: lineOptions }},
    { type: 'select', key: 'type', label: '任务类型', props: { options: TASK_TYPE }},
    { type: 'date', key: 'executionStartTime', label: '巡检时间', props: { type: 'datetime', valueFormat: 'yyyy-MM-dd HH:mm:ss', format: 'yyyy-MM-dd HH:mm:ss', isDateDisabled: (ts) => { return ts < (Date.now() - 24 * 60 * 60 * 1000) }, isTimeDisabled: disableTime }},
    { type: 'input', key: 'note', label: '备注', props: { type: 'textarea', autosize: { minRows: 3, maxRows: 3 }}}
  ]
})

export const getAirOptions = async function() {
  const res = await airportList()
  airOptions.value = dataToSelect(res.data, { label: 'name', value: 'droneId' })
}

// 获取角色列表
export const getLineOptions = async function(id) {
  const res = await airportLine(id)
  lineOptions.value = dataToSelect(res.data, { label: 'name', value: 'id' })
}

export const getOptions = function() {
  return {
    airOptions,
    lineOptions
  }
}
